# Instant Articles

**If you are seeking package for generating instant article or feeds then yes, this package is for you.**

> This helps you generate facebooks instant articles and also regular feeds with enough customizations you might need.

### How to?

#### Step 1: Install package

Install package by executing the command.

```shell
pip install masonite-instant-article
```

#### Step 2: Publish Files

You need to have some files and don't worry it's quite easy. You just want to execute the command now.

```shell
python craft package:publish instant_article
```
